#
# spec file for package libcec
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2012 Guillaume GARDET <guillaume@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   6
%define libname	%{name}%{sover}
%bcond_with enable_rpi_build
Name:           libcec
Version:        6.0.2
Release:        3.4
Summary:        Library to control devices with TV remote control via HDMI
License:        GPL-2.0-or-later
URL:            https://github.com/Pulse-Eight/libcec
Source:         https://github.com/Pulse-Eight/libcec/archive/libcec-%{version}.tar.gz
Patch1:         libcec-cmake_install_lib_dir.patch
# PATCH-FIX-UPSTREAM https://github.com/Pulse-Eight/libcec/pull/553
Patch2:         reproducible.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
BuildRequires:  swig
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(p8-platform)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(udev)
BuildRequires:  pkgconfig(xrandr)
%ifarch armv6l armv6hl
%if %{with enable_rpi_build}
BuildRequires:  raspberrypi-gfx-devel
%endif
%endif

%description
In combination with the right hardware, libcec allows to control
a device with a TV remote control utilizing existing HDMI
cabling.

libCEC is an enabling platform for the CEC bus in HDMI. It allows
developers to interact with other HDMI devices without having to
worry about the communication overhead, handshaking, and the various
ways of sending a message for each vendor.

%package -n cec-client
Summary:        Control your device with your TV remote control via HDMI
Group:          Hardware/TV
Requires:       %{libname} = %{version}

%description -n cec-client
In combination with the right hardware, libcec allows to control
a device with a TV remote control utilizing existing HDMI
cabling.

libCEC is an enabling platform for the CEC bus in HDMI, it allows
developers to interact with other HDMI devices without having to
worry about the communication overhead, handshaking, and the various
ways of sending a message for each vendor.

This package contains the client applications.

%package -n python3-%{name}
Summary:        Python bindings for %{name}
Group:          Hardware/TV

%description -n python3-%{name}
In combination with the right hardware, libcec allows to control
a device with a TV remote control utilizing existing HDMI
cabling.

libCEC is an enabling platform for the CEC bus in HDMI, it allows
developers to interact with other HDMI devices without having to
worry about the communication overhead, handshaking, and the various
ways of sending a message for each vendor.

This package contains the Python bindings.

%package -n %{libname}
Summary:        USB CEC adapter communication library
Group:          System/Libraries

%description -n %{libname}
In combination with the right hardware, libcec allows to control
a device with a TV remote control utilizing existing HDMI
cabling.

%package devel
Summary:        Development files for the USB CEC adapter communication library
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
libCEC is an enabling platform for the CEC bus in HDMI, it allows
developers to interact with other HDMI devices without having to
worry about the communication overhead, handshaking, and the various
ways of sending a message for each vendor.

This subpackage contains the headers for libcec.

%prep
%autosetup -n %{name}-%{name}-%{version} -p1

%build
%cmake \
  -Wno-dev
%cmake_build

%install
%cmake_install

%ldconfig_scriptlets -n %{libname}

%files -n cec-client
%defattr(755,root,root)
%{_bindir}/cec-client
%{_bindir}/cec-client-%{version}
%{_bindir}/cecc-client
%{_bindir}/cecc-client-%{version}

%files -n python3-%{name}
%{_bindir}/pyCecClient
%{python3_sitearch}/*

%files -n %{libname}
%license COPYING
%doc debian/changelog.in
%{_libdir}/libcec.so.%{sover}*

%files devel
%{_includedir}/libcec
%{_libdir}/pkgconfig/libcec.pc
%{_libdir}/libcec.so

%changelog
* Wed Jun 28 2023 Martin Pluskal <mpluskal@suse.com>
- Small packaging cleanup
* Wed Jun 28 2023 Ludwig Nussel <lnussel@suse.com>
- Don't buildrequire lockdev, it's not actually used
* Thu Feb 11 2021 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to drop build host name (boo#1084909)
* Thu Jan 14 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 6.0.2:
  * See provided changelog.in for detailed list of changes
- Drop no longer applying libcec-build-compare.patch
* Mon Feb 11 2019 Martin Pluskal <mpluskal@suse.com>
- Fix dependency handling for python3
* Wed Jan  9 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary. Generalize description.
* Mon Dec 31 2018 Martin Pluskal <mpluskal@suse.com>
- Update to version 4.0.4:
  * fixed: only prevent TV polls when a Samsung TV is detected
    instead of suppressing all logical addresses. issue #424 #444
- Changes for version 4.0.3:
  * fixed:
    + detect debian based distros properly when installing python. closes #314
    + don't filter out broadcast in HandleDeviceVendorCommandWithId(). issue
    [#309]
    + send an active source message when a routing change has been received with
    libCEC's address as new route and no active source message has been sent
    yet. issue #309 #205 #233
    + vs2015 c++ redistributables
    + fix missing tinfo linking in cec-client. #341
    + set wrong variable. #343 #352
    + LG - don't activate the source when receiving vendor command 0xB. #344
    + LG TV always changing input when turned on #307
    + Fix menu language string. #360
    + correct python lib path for python 2.7+/3+. #356
    + Fix build if tinfo library is not present. #398
    + disable autonomous mode when a Samsung TV is connected. Samsung 2017+ TVs
    will power on randomly (Samsung bug). don't poll the TV. #424
    + CRPiCECAdapterMessageQueue::Write() accessed the queue without locking.
    [#423]
    + use sig_atomic_t for shared object between sig handler and main. #425
    + python 3.5+ import. #356
    + TDA995x: Fix logical address readback. #303
    + TDA995x: Handle physical address change, optimize logical address setup.
    [#303]
    + Pulse-Eight USB CEC adapter detection on macOS Mojave. #434
    + Fix broken Python version check and failure to build on cmake < 3.7. #409
    + 13 char device name got truncated
  * changed:
    + log a warning when we detect that RPi's CEC service is used by something
    else, blocking libCEC. issue #191
    + const IAdapterCommunication::GetLogicalAddresses(), making the mutex
    mutable for now without changing the platform lib. closes #259
    + Add a Reinitialze action.  Useful for after the device has been powered
    down. #299
    + Panasonic media control info to the readme
    + detect WIN64 in cmake automatically. #322
    + README.developers.md. #330
    + instructions for hdmi_force_hotplug=1 on the pi
    + eventghost plugin install/create. #375
    + Include C version of libCEC loader when installing. #397
    + Explicitly use python3 in pyCecClient. #433
    + build with vs 2015
- Refresh patches:
  * libcec-cmake_install_lib_dir.patch
  * libcec-build-compare.patch
* Thu Mar  8 2018 mpluskal@suse.com
- Cleanup spec file
- Switch to python3
* Sun Feb 19 2017 sagiben@gmail.com
- Rebase libcec-cmake_install_lib_dir.patch
* Sun Feb 19 2017 mpluskal@suse.com
- Update to version 4.0.2:
  * don't automatically assume that an AVR is active in some
    situations
  * don't take Panasonic's vendor id when emulating an AVR
  * drm EDID parser not compiled in.
  * python: have Swig generate Python threading support
  * python: only pass unsigned
  * python: allow empty callback parameters
  * python: install demo app as executable
  * python: correct install path.
  * python: possible crash when passing an invalid callback
  * TransmitVolumeDown to use CEC_USER_CONTROL_CODE_VOLUME_DOWN.
  * HAVE_AOCEC_API missing in if in AdapterFactory.
  * env.h had 'ON' instead of '1' for some values
  * bAutoWakeAVR entry in libcec_configuration, which controls
    whether to automatically power on the avr or not when the
    source is activated.
  * iDoubleTapTimeoutMs replacing iDoubleTapTimeout50Ms. time is
    now in milliseconds
  * new AO CEC adapter.
  * compilation with full debugging enabled
  * handling of LG vendor command 0x0B.
  * return value wasn't checked correctly in
    CLibCEC::RegisterClient()
  * Raspberry Pi fixes for issues #252 and #191
* Mon Jan 25 2016 olaf@aepfle.de
- Reduce build-compare noise
  libcec-build-compare.patch
* Sat Jan 23 2016 mpluskal@suse.com
- Rename cmake_install_lib_dir.patch to
  libcec-cmake_install_lib_dir.patch
* Sat Jan 23 2016 sagiben@gmail.com
- Update to v3.1.0
- Add cmake_install_lib_dir.patch patch for better handling
  of libdir in .pc file and python packge installation path
- Update dependency to libp8-platform
* Sat Jan  2 2016 mpluskal@suse.com
- Fix path to libdir in .pc file (boo#960475)
* Mon Nov 16 2015 christof.hanke@induhviduals.de
- Explictly require package libcec by package cec-client since the
  library is loaded via dlopen.
* Sat Jul 18 2015 mpluskal@suse.com
- Update to 3.0.1
  * no upstream changelog provided
* Fri Jun 12 2015 mpluskal@suse.com
- Revert name change
- Use %%cmake macro
- Cleanup spec file with spec-cleaner
- Use url for source
- Fix non stanard changelog entry
- Split python package
- Update dependencies (add swig, drop autotools)
- libcec-no-buildtime.patch and configure.ac.diff were dropped by
  previous change
- Update name of source dir
* Mon Jun  1 2015 sagiben@gmail.com
- Update to v3.0.0
* Mon Feb  2 2015 olaf@aepfle.de
- Remove timestamps from binary to reduce build-compare noise
  libcec-no-buildtime.patch
* Thu Dec 25 2014 jengelh@inai.de
- Implement shared library packaging guidelines
* Wed Nov 26 2014 sagiben@gmail.com
- Update to v2.2.0
* Mon Sep 16 2013 guillaume@opensuse.org
- Remove old tar.gz from 2.1.1 version
* Tue Sep  3 2013 guillaume@opensuse.org
- Cleanup for submition to devel project:
  * clean section removed
  * --disable-static option added and remove libcec.la
  * make use of paralel build: "make %%{?_smp_mflags}"
* Mon Aug 26 2013 guillaume@opensuse.org
- Add '%%bcond_with enable_rpi_build' for armv6
* Mon Aug 26 2013 guillaume@opensuse.org
- Update to v2.1.3
* Thu Mar 21 2013 guillaume@opensuse.org
- Update to v2.1.1
* Tue Dec 11 2012 guillaume@opensuse.org
- Update to v2.0.5 (repacked version)
* Fri Oct 19 2012 guillaume@opensuse.org
- Initial Release (v2.0.4)
